package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.OrderCallMapper;
import com.ruoyi.system.domain.OrderCall;
import com.ruoyi.system.service.IOrderCallService;

/**
 * 订单通话记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class OrderCallServiceImpl implements IOrderCallService 
{
    @Autowired
    private OrderCallMapper orderCallMapper;

    /**
     * 查询订单通话记录
     * 
     * @param id 订单通话记录主键
     * @return 订单通话记录
     */
    @Override
    public OrderCall selectOrderCallById(Integer id)
    {
        return orderCallMapper.selectOrderCallById(id);
    }


    public List<OrderCall> selectOrderCallByOid(Long oid){
        return orderCallMapper.selectOrderCallByOid(oid);
    }

    public int selectCountOrderCallByOid(Long oid){
        return orderCallMapper.selectCountOrderCallByOid(oid);
    }
    /**
     * 查询订单通话记录列表
     * 
     * @param orderCall 订单通话记录
     * @return 订单通话记录
     */
    @Override
    public List<OrderCall> selectOrderCallList(OrderCall orderCall)
    {
        return orderCallMapper.selectOrderCallList(orderCall);
    }

    /**
     * 新增订单通话记录
     * 
     * @param orderCall 订单通话记录
     * @return 结果
     */
    @Override
    public int insertOrderCall(OrderCall orderCall)
    {
        return orderCallMapper.insertOrderCall(orderCall);
    }

    /**
     * 修改订单通话记录
     * 
     * @param orderCall 订单通话记录
     * @return 结果
     */
    @Override
    public int updateOrderCall(OrderCall orderCall)
    {
        return orderCallMapper.updateOrderCall(orderCall);
    }

    /**
     * 批量删除订单通话记录
     * 
     * @param ids 需要删除的订单通话记录主键
     * @return 结果
     */
    @Override
    public int deleteOrderCallByIds(Integer[] ids)
    {
        return orderCallMapper.deleteOrderCallByIds(ids);
    }

    /**
     * 删除订单通话记录信息
     * 
     * @param id 订单通话记录主键
     * @return 结果
     */
    @Override
    public int deleteOrderCallById(Integer id)
    {
        return orderCallMapper.deleteOrderCallById(id);
    }
}
