package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.OrderCall;
import com.ruoyi.system.service.IOrderCallService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单通话记录Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/OrderCall")
public class OrderCallController extends BaseController
{
    @Autowired
    private IOrderCallService orderCallService;

    /**
     * 查询订单通话记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:OrderCall:list')")
    @GetMapping("/list")
    public TableDataInfo list(OrderCall orderCall)
    {
        startPage();
        List<OrderCall> list = orderCallService.selectOrderCallList(orderCall);
        return getDataTable(list);
    }

    /**
     * 导出订单通话记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:OrderCall:export')")
    @Log(title = "订单通话记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OrderCall orderCall)
    {
        List<OrderCall> list = orderCallService.selectOrderCallList(orderCall);
        ExcelUtil<OrderCall> util = new ExcelUtil<OrderCall>(OrderCall.class);
        util.exportExcel(response, list, "订单通话记录数据");
    }

    /**
     * 获取订单通话记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:OrderCall:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(orderCallService.selectOrderCallById(id));
    }

    /**
     * 新增订单通话记录
     */
    @PreAuthorize("@ss.hasPermi('system:OrderCall:add')")
    @Log(title = "订单通话记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody OrderCall orderCall)
    {
        return toAjax(orderCallService.insertOrderCall(orderCall));
    }

    /**
     * 修改订单通话记录
     */
    @PreAuthorize("@ss.hasPermi('system:OrderCall:edit')")
    @Log(title = "订单通话记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody OrderCall orderCall)
    {
        return toAjax(orderCallService.updateOrderCall(orderCall));
    }

    /**
     * 删除订单通话记录
     */
    @PreAuthorize("@ss.hasPermi('system:OrderCall:remove')")
    @Log(title = "订单通话记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(orderCallService.deleteOrderCallByIds(ids));
    }
}
